@@ -13,8 +13,11 @@
 #' @importFrom wikitaxa wt_wikipedia
 #' @importFrom taxize gbif_parse
 #' @examples
-#' list_wiki_syn("Abrothrix illutea")
-#' #list_wiki_syn(c("Abditomys latidens", "Abeomelomys sevia", "Abrocoma schistacea"))
+#' \dontrun{
+#'  list_wiki_syn("Abrothrix illutea")
+#'  list_wiki_syn(c("Abditomys latidens", "Abeomelomys sevia",
+#'                  "Abrocoma schistacea"))
+#' }
 #'
 #' @export
 list_wiki_syn <- function(namelist,verbose = TRUE){
@@ -26,7 +29,11 @@ list_wiki_syn <- function(namelist,verbose = TRUE){
     wikiacn <- wikitaxa::wt_wikipedia(accname)$classification[which(wt_wikipedia(namelist[i])$classification$rank=="binomial"),]$name
     if(!is.null(wikiacn) & !identical(wikiacn, character(0)) ){
       if(accname!= wikiacn){
-        wikisyn <- c(wikisyn,wikiacn)
+        if(length(wikisyn)>0){
+          wikisyn <- c(wikisyn,wikiacn)
+        } else {
+          wikisyn <- wikiacn
+        }
       }
     }
     if(length(wikisyn)>0){
@@ -46,7 +53,6 @@ list_wiki_syn <- function(namelist,verbose = TRUE){
           synrec$wikiacn <- wikiacn
         }
         synrec$accname <- accname
-        #synrec <- cbind(accname,wikiacn,syn_orig,syn)
         synlst <- rbind(synlst,synrec)
         if(verbose){cat("+")}
       }
@@ -62,4 +68,4 @@ list_wiki_syn <- function(namelist,verbose = TRUE){
   }
   if(verbose){cat("\n")}
   return(res)
-}
+}
\ No newline at end of file
